Route Providers — plone.jsonapi.routes 0.4 documentation

### Navigation

- index
- modules |
- plone.jsonapi.routes 0.4 documentation »

# Route Providers

`plone.jsonapi.routes.` `add_plone_route`(rule, endpoint=None, **kw)

  add a Plone JSON API route

`plone.jsonapi.routes.` `api_json`(context, request)

  API URLs

`plone.jsonapi.routes.` `get_api_routes_for`(segment)

  return a list of all routes registered for the given url segment

`plone.jsonapi.routes.` `initialize`(context)

  Initializer called when used as a Zope 2 product.

### Navigation

- index
- modules |
- plone.jsonapi.routes 0.4 documentation »